@@ -121,8 +121,8 @@ def main():
     help='Do not apply a lock while executing the command (only applicable with plan)',
     show_default=True
     )
-@click.option('--update-source', '-u', is_flag=True, default=False,
-    help='Run the command including the --terragrunt-source-update option',
+@click.option('--update', '-u', is_flag=True, default=False,
+    help='Updates the source (and/or provider if applicable)',
     show_default=True
     )
 @click.option('--planfile', '-p', is_flag=True, default=False,
@@ -139,7 +139,7 @@ def main():
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
-def run(command, verbose, debug, dry_run, no_lock, update_source,
+def run(command, verbose, debug, dry_run, no_lock, update,
     planfile, auto_approve, working_dir, terragrunt_args):
     """ [default] Executes a terragrunt command on a single project """
 
@@ -151,7 +151,7 @@ def run(command, verbose, debug, dry_run, no_lock, update_source,
         debug=debug,
         dry_run=dry_run,
         no_lock=no_lock,
-        update_source=update_source,
+        update=update,
         planfile=planfile,
         auto_approve=auto_approve,
         working_dir=working_dir,
@@ -181,8 +181,8 @@ def run(command, verbose, debug, dry_run, no_lock, update_source,
     help='Do not apply a lock while executing the command (only applicable with plan)',
     show_default=True
     )
-@click.option('--update-source', '-u', is_flag=True, default=False,
-    help='Run the command including the --terragrunt-source-update option',
+@click.option('--update', '-u', is_flag=True, default=False,
+    help='Updates the source (and/or provider if applicable)',
     show_default=True
     )
 @click.option('--exclude-external-dependencies', '-x', is_flag=True, default=False,
@@ -197,10 +197,6 @@ def run(command, verbose, debug, dry_run, no_lock, update_source,
     help='Use the generated planfile when applying the changes',
     show_default=True
     )
-# @click.option('--auto-approve/--no-auto-approve', is_flag=True, default=True,
-#     help='Do not ask for confirmation before applying planned changes (where applicable)',
-#     show_default=True
-#     )
 @click.option('--auto-approve', '-a', is_flag=True, default=False,
     help='Do not ask for confirmation before applying planned changes (where applicable)',
     show_default=True
@@ -215,7 +211,7 @@ def run(command, verbose, debug, dry_run, no_lock, update_source,
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
-def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_external_dependencies,
+def run_all(command, verbose, debug, dry_run, no_lock, update, exclude_external_dependencies,
     step_by_step, planfile, auto_approve, working_dir, limit_parallelism, terragrunt_args):
     """ Executes a terragrunt command across multiple projects """
 
@@ -227,7 +223,7 @@ def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_ex
         debug=debug,
         dry_run=dry_run,
         no_lock=no_lock,
-        update_source=update_source,
+        update=update,
         exclude_external_dependencies=exclude_external_dependencies,
         step_by_step=step_by_step,
         planfile=planfile,
