@@ -53,36 +53,43 @@ class TgWrap():
         return shutil.which(program) is not None
 
     def _construct_command(self, command, debug, exclude_external_dependencies,
-        non_interactive=True, no_auto_approve=True, no_lock=True, update_source=False,
+        non_interactive=True, no_auto_approve=True, no_lock=True, update=False,
         planfile=None, working_dir=None, limit_parallelism=None, terragrunt_args=()):
         """ Constructs the command """
+
+        PLANFILE_NAME="planfile"
+
         commands = {
-            'generic': '{base_command} {command} --terragrunt-non-interactive {no_auto_approve} {ignore_deps} {debug_level} {update_source} {working_dir} {parallelism} {terragrunt_args}',
-            'info': '{base_command} terragrunt-info --terragrunt-non-interactive {ignore_deps} {debug_level} {update_source} {working_dir} {terragrunt_args}',
-            'plan': '{base_command} {command} --terragrunt-non-interactive  -out=planfile {ignore_deps} {debug_level} {lock_level} {update_source} {working_dir} {parallelism} {terragrunt_args}',
-            'apply': '{base_command} {command} {non_interactive} {no_auto_approve} {parallelism} {ignore_deps} {debug_level} {update_source} {working_dir} {parallelism} {terragrunt_args} {planfile}',
-            'show': '{base_command} {command} --terragrunt-non-interactive {ignore_deps} {update_source} -json planfile', # no working dir allowed here!!!
+            'generic': '{base_command} {command} --terragrunt-non-interactive {no_auto_approve} {ignore_deps} {debug_level} {update} {working_dir} {parallelism} {terragrunt_args}',
+            'info': '{base_command} terragrunt-info --terragrunt-non-interactive {ignore_deps} {debug_level} {update} {working_dir} {terragrunt_args}',
+            'plan': '{base_command} {command} --terragrunt-non-interactive  -out={planfile_name} {ignore_deps} {debug_level} {lock_level} {update} {working_dir} {parallelism} {terragrunt_args}',
+            'apply': '{base_command} {command} {non_interactive} {no_auto_approve} {parallelism} {ignore_deps} {debug_level} {update} {working_dir} {parallelism} {terragrunt_args} {planfile}',
+            'show': '{base_command} {command} --terragrunt-non-interactive {ignore_deps} {update} -json {planfile_name}', # no working dir allowed here!!!
             'destroy': '{base_command} {command} {non_interactive} {no_auto_approve} {ignore_deps} {debug_level} {working_dir} {parallelism} {terragrunt_args} {planfile}',
         }
 
         lock_stmt         = '-lock=false' if no_lock else ''
-        update_stmt       = '--terragrunt-source-update' if update_source else ''
+        update_stmt       = '--terragrunt-source-update' if update else ''
         ignore_deps_stmt  = '--terragrunt-ignore-external-dependencies' if exclude_external_dependencies else '--terragrunt-include-external-dependencies'
         debug_stmt        = '--terragrunt-log-level debug --terragrunt-debug' if debug else ''
         auto_approve_stmt = '--terragrunt-no-auto-approve' if no_auto_approve else ''
         interactive_stmt  = '--terragrunt-non-interactive' if non_interactive else ''
         working_dir_stmt  = f'--terragrunt-working-dir {working_dir}' if working_dir else ''
         parallelism_stmt  = f'--terragrunt-parallelism {limit_parallelism}' if limit_parallelism else ''
-        planfile_stmt     = 'planfile' if planfile else ''
+        planfile_stmt     = f'{PLANFILE_NAME}' if planfile else ''
 
         base_command      = 'terragrunt run-all'
 
+        # if we are using an 'init' together with update, add the `-upgrade` as well
+        if command.lower() == 'init' and update:
+            update_stmt       = '--terragrunt-source-update -update'
+
         if command not in ['clean']:
             full_command = commands.get(command, commands.get('generic')).format(
                 base_command=base_command,
                 command=command,
                 lock_level=lock_stmt,
-                update_source=update_stmt,
+                update=update_stmt,
                 ignore_deps=ignore_deps_stmt,
                 debug_level=debug_stmt,
                 no_auto_approve=auto_approve_stmt,
@@ -90,6 +97,7 @@ class TgWrap():
                 working_dir=working_dir_stmt,
                 parallelism=parallelism_stmt,
                 planfile=planfile_stmt,
+                planfile_name=PLANFILE_NAME,
                 terragrunt_args=' '.join(terragrunt_args),
             )
         else:
@@ -357,7 +365,7 @@ class TgWrap():
             rc = subprocess.run(shlex.split(cmd))
             self.printer.verbose(rc)
 
-    def run(self, command, debug, dry_run, no_lock, update_source,
+    def run(self, command, debug, dry_run, no_lock, update,
         planfile, auto_approve, working_dir, terragrunt_args):
         """ Executes a terragrunt command on a single module """
 
@@ -379,7 +387,7 @@ class TgWrap():
             debug=debug,
             exclude_external_dependencies=True,
             no_lock=no_lock,
-            update_source=update_source,
+            update=update,
             planfile=planfile,
             no_auto_approve=(not auto_approve),
             working_dir=working_dir,
@@ -395,7 +403,7 @@ class TgWrap():
             rc = subprocess.run(shlex.split(cmd, posix=False))
             self.printer.verbose(rc)
 
-    def run_all(self, command, debug, dry_run, no_lock, update_source,
+    def run_all(self, command, debug, dry_run, no_lock, update,
         exclude_external_dependencies, step_by_step, planfile, auto_approve, 
         working_dir, limit_parallelism, terragrunt_args):
         """ Executes a terragrunt command across multiple modules """
@@ -414,7 +422,7 @@ class TgWrap():
             exclude_external_dependencies=True if step_by_step else exclude_external_dependencies,
             non_interactive=True if step_by_step else auto_approve,
             no_lock=no_lock,
-            update_source=update_source,
+            update=update,
             planfile=planfile,
             no_auto_approve=False if step_by_step else (not auto_approve),
             working_dir=None if step_by_step else working_dir,
@@ -620,6 +628,9 @@ class TgWrap():
             self.printer.verbose(f"No target stage given, assume the same as source stage")
             target_stage=source_stage
 
+        if not source_domain and not target_domain and not target_stage:
+            raise Exception("When not providing domains, you need to provide a target stage!")
+
         # do we have a working dir?
         working_dir = working_dir if working_dir else os.getcwd()
         # the domains will be ignored when omitted as input
